@@ -13,30 +13,30 @@ sub update {
 	my ($self, $screen_surface) = @_;
 
 	for (my $i = 0; $i < length($self->{entities}); $i++) {
-		$self->{entities}->update;
-		$self->{entities}->blit($screen_surface);
+		$self->{entities}[$i]->update;
+		$self->{entities}[$i]->blit($self->{x}, $self->{y}, $screen_surface);
 	}
 }
 
-sub moveleft {
+sub move_left {
 	my ($self) = shift;
 
 	$self->{x}--;
 }
 
-sub moveright {
+sub move_right {
 	my ($self) = shift;
 
 	$self->{x}++;
 }
 
-sub moveup {
+sub move_up {
 	my ($self) = shift;
 
 	$self->{y}--;
 }
 
-sub movedown {
+sub move_down {
 	my ($self) = shift;
 
 	$self->{y}++;
